@@ -22,8 +22,7 @@
 #ifndef KDATETABLE_H
 #define KDATETABLE_H
 
-#include <QLineEdit>
-#include <QtCore/QDateTime>
+#include <QWidget>
 
 class QMenu;
 
@@ -51,17 +50,17 @@ public:
     /**
      * The constructor.
      */
-    explicit KDateTable(QWidget *parent = 0);
+    explicit KDateTable(QWidget *parent = nullptr);
 
     /**
      * The constructor.
      */
-    explicit KDateTable(const QDate &, QWidget *parent = 0);
+    explicit KDateTable(const QDate &, QWidget *parent = nullptr);
 
     /**
      * The destructor.
      */
-    ~KDateTable();
+    ~KDateTable() override;
 
     /**
      * Returns a recommended size for the widget.
@@ -70,7 +69,7 @@ public:
      * to be done there anyway. The size is stored in maxCell. The
      * sizeHint() simply returns a multiple of maxCell.
      */
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
     /**
      * Set the font size of the date table.
@@ -128,21 +127,21 @@ protected:
      */
     virtual QDate dateFromPos(int pos);
 
-    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *e) override;
 
     /**
      * React on mouse clicks that select a date.
      */
-    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-    void wheelEvent(QWheelEvent *e) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
-    void focusInEvent(QFocusEvent *e) Q_DECL_OVERRIDE;
-    void focusOutEvent(QFocusEvent *e) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *e) override;
+    void wheelEvent(QWheelEvent *e) override;
+    void keyPressEvent(QKeyEvent *e) override;
+    void focusInEvent(QFocusEvent *e) override;
+    void focusOutEvent(QFocusEvent *e) override;
 
     /**
      * Cell highlight on mouse hovering
      */
-    bool event(QEvent *e) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) override;
 
 Q_SIGNALS:
     /**
@@ -170,14 +169,6 @@ Q_SIGNALS:
      */
     void aboutToShowContextMenu(QMenu *menu, const QDate &date);
 
-private:
-    Q_PRIVATE_SLOT(d, void nextMonth())
-    Q_PRIVATE_SLOT(d, void previousMonth())
-    Q_PRIVATE_SLOT(d, void beginningOfMonth())
-    Q_PRIVATE_SLOT(d, void endOfMonth())
-    Q_PRIVATE_SLOT(d, void beginningOfWeek())
-    Q_PRIVATE_SLOT(d, void endOfWeek())
-
 private:
     class KDateTablePrivate;
     friend class KDateTablePrivate;
